require 'csv'
require_relative 'player'
require_relative 'game_turn'
require_relative 'treasure_trove'

module StudioGame
  class Game
    attr_reader :title

    def initialize(name)
      @title = name.capitalize
      @round_number = 1
      @players = []
    end

    def add_player(player)
      @players.push(player)
    end

    def play
      puts "Round #{@round_number}"
      @players.each do |player|
        GameTurn.take_turn(player)
      end

      @round_number += 1
      puts print_stats
    end

    def load_players(filename)
      players = CSV.open filename, headers: false

      players.each do |row|
        name = row[0]
        health = Integer(row[1])
        add_player(Player.new(name, health))
      end
    end

    def print_treasures
      treasures = TreasureTrove::TREASURES
      puts "There are #{treasures.size} treasures to be found."
      treasures.each do |t|
        puts
      end
    end

    def save_stats(filename="./bin/highscores.txt")
      File.open(filename, "w") do |file|
        @players.each do |player|
          file.puts "#{player.name}..........#{player.score}"
        end
      end
    end

    def print_stats
      strong, whimpy = @players.partition { |p| p.strong?}

      puts "\n#{@title} Statistics:\n#{strong.size} strong players:"
      strong.each do |p|
        puts "#{p.name} (#{p.health})"
      end

      puts "\n#{whimpy.size} whimpy players:"
      whimpy.each do |p|
        puts "#{p.name} (#{p.health})"
      end

      sorted_players = @players.sort { |a, b| b.score <=> a.score}

      puts "\n#{@title} Scores:"
      sorted_players.each do |p|
        puts "#{p.name} (#{p.health}):\n#{p.points} total points\nTreasures:"
        p.each_found_treasure do |treasure|
          puts "#{treasure.points} total #{treasure.name} points"
        end
      end
    end
  end
end
